/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef CONSOLE_DIALOG_INCLUDED
#define CONSOLE_DIALOG_INCLUDED

#include <QtGui/QDialog>
class QTextEdit;

//! 実行されたコマンドや出力されたエラーメッセージを表示するダイアログ
class ConsoleDialog : public QDialog
{
	Q_OBJECT

	public:
		explicit ConsoleDialog(QWidget *parent = 0);

		//! 実行されたコマンドを表示する
		void execute(const QString &command);
		//! 出力されたエラーメッセージを表示する
		void readStandardError(const QByteArray &output);

	private:
		// don't implement these
		ConsoleDialog(const ConsoleDialog &);
		ConsoleDialog &operator=(const ConsoleDialog &);

		QTextEdit *consoleTextEdit;
};
#endif // CONSOLE_DIALOG_INCLUDED
